@@ -13,18 +13,24 @@ class LibraryItem;
 class QPushButton;
 class QGraphicsProxyWidget;
 
-class MAINMODULE_EXPORT SwitchDip : public Component, public eElement
+class SwitchDip : public Component, public eElement
 {
     public:
         SwitchDip( QString type, QString id );
         ~SwitchDip();
 
         static Component* construct( QString type, QString id );
-        static LibraryItem *libraryItem();
+        static LibraryItem* libraryItem();
 
         int  size() { return m_size; }
         void setSize( int size );
 
+        bool exclusive() { return m_exclusive; }
+        void setExclusive( bool e );
+
+        bool commonPin() { return m_commonPin; }
+        void setCommonPin( bool c );
+
         int  state() { return m_state; }
         void setState( int state );
 
@@ -35,7 +41,11 @@ class MAINMODULE_EXPORT SwitchDip : public Component, public eElement
         void createSwitches( int c );
         void deleteSwitches( int d );
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void setHidden( bool hid, bool hidArea=false, bool hidLabel=false ) override;
+
+        virtual void setLinkedValue( double v, int i=0 ) override;
+
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 
     public slots:
         void onbuttonclicked();
@@ -44,6 +54,9 @@ class MAINMODULE_EXPORT SwitchDip : public Component, public eElement
         QList<QPushButton*> m_buttons;
         QList<QGraphicsProxyWidget*> m_proxys;
 
+        bool m_exclusive;
+        bool m_commonPin;
+
         int m_size;
         int m_state;
 };
