@@ -46,7 +46,7 @@ bool BaseDebugger::upload()
         ok = Mcu::self()->load( m_firmware );
         if( ok ) m_outPane->appendText( "\n"+tr("FirmWare Uploaded to ") );
         else     m_outPane->appendText( "\n"+tr("Error uploading firmware to ") );
-        m_outPane->appendLine( Mcu::self()->device() );
+        m_outPane->appendLine( Mcu::self()->idLabel()+"("+ Mcu::self()->device() +")" );
         m_outPane->appendLine( m_firmware+"\n" );
     }
     if( ok ){
@@ -124,9 +124,8 @@ bool BaseDebugger::postProcess()
                 words.removeAll("");
                 if( words.isEmpty() ) continue;
                 str = words.first();
-                bool ok = false;
-                srcLineNumber = str.toInt( &ok );
-                if( ok ) found = true;
+
+                srcLineNumber = str.toInt( &found ); // src line number found
             }
         }
     }
@@ -212,6 +211,7 @@ void BaseDebugger::run()
     m_running = true;
     stepFromLine();
 }
+
 void BaseDebugger::pause()
 {
     m_running = false;
@@ -249,7 +249,7 @@ void BaseDebugger::stepDebug()
 
     if( lastPC != PC )
     {
-        if( m_over ){       // Step Over entry
+        if( m_over ){                                 // Step Over entry
             if( m_functions.values().contains( PC ) )
             {
                 m_exitPC = eMcu::self()->cpu()->RET_ADDR();
@@ -257,7 +257,7 @@ void BaseDebugger::stepDebug()
                 return;
             }
         }
-        if( m_exitPC )     // Step Over exit
+        if( m_exitPC )                               // Step Over exit
         {
             if( PC == m_exitPC ) m_exitPC = 0;
             else return;
